<template>
  <div class="app-container flex-d-b bb">
    <div class="top-srarch flex">
      <el-form
        :model="queryParams"
        ref="queryForm"
        :inline="true"
        v-show="showSearch"
      >
        <el-form-item label="选择任务年份" prop="year">
          <el-date-picker
            v-model="queryParams.year"
            type="year"
            value-format="yyyy"
            placeholder="选择年"
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item label="任务名称" prop="title">
          <el-input
            v-model="queryParams.title"
            placeholder="请输入任务名称"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
          />
        </el-form-item>
        <!--<el-form-item label="用户类型，1是居民，2是工商户，3是工业" prop="type">-->
        <!--<el-select v-model="queryParams.type" placeholder="请选择用户类型，1是居民，2是工商户，3是工业" clearable size="small">-->
        <!--<el-option label="请选择字典生成" value="" />-->
        <!--</el-select>-->
        <!--</el-form-item>-->
        <!--<el-form-item label="任务状态 0进行中 1已结束" prop="status">-->
        <!--<el-select v-model="queryParams.status" placeholder="请选择任务状态 0进行中 1已结束" clearable size="small">-->
        <!--<el-option label="请选择字典生成" value="" />-->
        <!--</el-select>-->
        <!--</el-form-item>-->
        <el-form-item>
          <el-button
            type="primary"
            icon="el-icon-search"
            size="mini"
            @click="handleQuery"
            >搜索</el-button
          >
          <!-- <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
            >重置</el-button
          > -->
        </el-form-item>
      </el-form>
      <div class="add">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['checktask:task:add']"
          >新建任务</el-button
        >
      </div>
    </div>

    <transition-group
      class="middle bb flex-b flex-w"
      name="breadcrumb"
      tag="div"
    >
      <ItemJc
        v-for="item in taskList"
        :key="item.title"
        :itemData="item"
        class="item"
        @handleDetail="handleDetail"
        @handleUpdate="handleUpdate"
        @handleDelete="handleDelete"
        @handleEnd="handleEnd"
        @handleVisitorMiss="handleVisitorMiss"
      />
    </transition-group>

    <!-- <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['checktask:task:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['checktask:task:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['checktask:task:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
		  :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['checktask:task:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row> -->

    <!-- <el-table
      v-loading="loading"
      :data="taskList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column
        label="任务标题"
        align="center"
        prop="title"
        width="130"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="任务描述"
        align="center"
        prop="describe"
        width="150"
        :show-overflow-tooltip="true"
      />



      <el-table-column label="用户类型，1是居民，2是工商户，3是工业" align="center" prop="type" />
      <el-table-column label="工业安检类型 1月度巡检 2季度巡检" align="center" prop="checkType" />



      <el-table-column
        label="起止日期"
        align="center"
        prop="startTime"
        width="200"
      >
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.startTime, "{y}-{m}-{d}") }}</span>
          <span>至{{ parseTime(scope.row.endTime, "{y}-{m}-{d}") }}</span>
        </template>
      </el-table-column>



       <el-table-column label="结束日期" align="center" prop="endTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.endTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>



      <el-table-column label="任务状态" align="center" prop="status">
        <template slot-scope="scope">
          <span v-if="scope.row.status == 0" style="color: green">进行中</span>
          <span v-if="scope.row.status == 1" style="color: red"> 已结束</span>
        </template>
      </el-table-column>
      <el-table-column label="创建人" align="center" prop="nickname" />
      <el-table-column
        label="创建时间"
        align="center"
        prop="createTime"
        width="150"
      />
      <el-table-column label="完成率/数" align="center" prop="inspcetTotal" />
      <el-table-column label="备注" align="center" prop="remarks" />
      <el-table-column
        label="操作"
        align="center"
        width="180"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-document"
            @click="handleDetail(scope.row)"
            >详情</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['checktask:task:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['checktask:task:remove']"
            >删除</el-button
          >
          <el-button
            size="mini"
            type="text"
            @click="handleEnd(scope.row)"
            v-if="scope.row.status != 1"
            v-hasPermi="['checktask:task:end']"
            >结束</el-button
          >
        </template>
      </el-table-column>
    </el-table> -->

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      :pageSizes="[queryParams.pageSize]"
      @pagination="getList"
    />

    <!-- 添加或修改商业安检任务对话框 -->
    <el-dialog
      :title="title"
      :visible.sync="open"
      width="500px"
      append-to-body
      :close-on-click-modal="false"
    >
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="任务标题" prop="title">
          <el-input v-model="form.title" placeholder="请输入任务名称" />
        </el-form-item>
        <el-form-item label="任务描述" prop="describe">
          <el-input
            type="textarea"
            v-model="form.describe"
            placeholder="请输入任务描述"
          />
        </el-form-item>

        <el-form-item label="安检类型" prop="businessType">
          <el-select v-model="form.businessType" placeholder="请选择安检类型">
            <el-option
              v-for="dict in typeOptions"
              :key="dict.id"
              :label="dict.name"
              :value="dict.id"
            ></el-option>
          </el-select>
        </el-form-item>
        <!--<el-form-item label="用户类型，1是居民，2是工商户，3是工业" prop="type">-->
        <!--<el-select v-model="form.type" placeholder="请选择用户类型，1是居民，2是工商户，3是工业">-->
        <!--<el-option label="请选择字典生成" value="" />-->
        <!--</el-select>-->
        <!--</el-form-item>-->
        <!--<el-form-item label="工业安检类型 1月度巡检 2季度巡检" prop="checkType">-->
        <!--<el-select v-model="form.checkType" placeholder="请选择工业安检类型 1月度巡检 2季度巡检">-->
        <!--<el-option label="请选择字典生成" value="" />-->
        <!--</el-select>-->
        <!--</el-form-item>-->
        <el-form-item label="开始日期" prop="startTime">
          <el-date-picker
            clearable
            size="small"
            v-model="form.startTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="选择开始日期"
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item label="结束日期" prop="endTime">
          <el-date-picker
            clearable
            size="small"
            v-model="form.endTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="选择结束日期"
          >
          </el-date-picker>
        </el-form-item>
        <!--<el-form-item label="任务状态 0进行中 1已结束">-->
        <!--<el-radio-group v-model="form.status">-->
        <!--<el-radio label="1">请选择字典生成</el-radio>-->
        <!--</el-radio-group>-->
        <!--</el-form-item>-->
        <!--<el-form-item label="创建人" prop="adminId">-->
        <!--<el-input v-model="form.adminId" placeholder="请输入创建人" />-->
        <!--</el-form-item>-->
        <el-form-item label="备注" prop="remarks">
          <el-input
            type="textarea"
            v-model="form.remarks"
            placeholder="请输入备注"
          />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <el-dialog
      title="到访不遇信息"
      :visible.sync="visitorDialogOpen"
      width="1200px"
      append-to-body
      :close-on-click-modal="false"
    >
      <VisitorMissInfo
        v-if="visitorDialogOpen"
        :taskDetailData="taskDetailData"
      />
    </el-dialog>
  </div>
</template>

<script>
import {
  listTask,
  getTask,
  delTask,
  addTask,
  updateTask,
  exportTask,
} from "@/api/checktask/task";
import ItemJc from "./components/ItemJc.vue";
import VisitorMissInfo from "./components/VisitorMissInfo";
export default {
  name: "Task",
  components: {
    ItemJc,
    VisitorMissInfo
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 商业安检任务表格数据
      taskList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        year: null,
        pageSize: 4,
        title: null,
        type: 2,
        status: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        title: [
          { required: true, message: "任务名称不能为空", trigger: "blur" },
        ],
        describe: [
          { required: true, message: "任务描述不能为空", trigger: "blur" },
        ],
        startTime: [
          { required: true, message: "开始日期不能为空", trigger: "blur" },
        ],
        endTime: [
          { required: true, message: "结束日期不能为空", trigger: "blur" },
        ],
        businessType: [
          { required: true, message: "请选择安检类型", trigger: "change" },
        ],
      },
      visitorDialogOpen: false,
      taskDetailData:{},
      typeOptions: [
        {
          id: "1",
          name: "华鑫季度一次",
        },
        {
          id: "2",
          name: "华鑫半年一次",
        },
        {
          id: "3",
          name: "鸿海季度一次",
        },
        {
          id: "4",
          name: "鸿海半年一次",
        },
      ],
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询商业安检任务列表 */
    getList() {
      this.loading = true;
      listTask(this.queryParams).then((response) => {
        this.taskList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        title: null,
        describe: null,
        type: 2,
        checkType: null,
        businessType: null,
        startTime: null,
        endTime: null,
        status: 0,
        adminId: null,
        createTime: null,
        remarks: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加商业安检任务";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getTask(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改商业安检任务";
      });
    },
    //详情
    handleDetail(row) {
      //this.$router.push("inspect?taskId="+row.id)
      this.$router.push({
        path: "/checktask/cyInspect",
        query: { taskId: row.id,type:row.type, taskType: row.businessType },
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateTask(this.form).then((response) => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTask(this.form).then((response) => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm(
        '是否确认删除商业安检任务编号为"' + ids + '"的数据项?',
        "警告",
        {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning",
        }
      )
        .then(function () {
          return delTask(ids);
        })
        .then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm("是否确认导出所有商业安检任务数据项?", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          this.exportLoading = true;
          return exportTask(queryParams);
        })
        .then((response) => {
          this.download(response.msg);
          this.exportLoading = false;
        })
        .catch(() => {});
    },
    handleEnd(row) {
      this.$confirm(
        '是否确认结束商业安检任务名称为"' + row.title + '"的数据项?',
        "警告",
        {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning",
        }
      )
        .then(function () {
          return updateTask({ id: row.id, status: 1 });
        })
        .then(() => {
          this.getList();
          this.msgSuccess("任务关闭成功！");
        })
        .catch(() => {});
    },
    handleVisitorMiss(row){
      this.visitorDialogOpen = true;
      this.taskDetailData = row;
    }
  },
};
</script>
<style lang="scss" scoped>
::v-deep .el-select {
  width: 100%;
}
::v-deep .el-date-editor.el-input,
.el-date-editor.el-input__inner {
  width: 100%;
}
.app-container {
  height: calc(100vh - 50px);
  width: 100%;
  padding-bottom: 43px;
  padding-right: 118px;
  padding-left: 90px;
  overflow: auto;


  .middle {
    flex: 1;
    // background: red;
    padding-top: 10px;
    align-content: space-between;
  }
}
.top-srarch {
  margin-bottom: 10px;

  // align-items: center;
  border-bottom: 1px solid #eeeeee;
}
.add {
  height: 36px;
  margin-top: 5px;
}
</style>
